.. Rulez documentation master file, created by
   sphinx-quickstart on Wed Nov  4 15:37:39 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

rulez: JSON based conditional rules
====================================

Rulez is a library that help with defining comparator/conditional operations declaratively
through dictionary / JSON structure. Currently, it provides a compiler that 
compiles the declarative rules into python function, sqlalchemy comparators/conditions,
and elasticsearch comparators.
